@@ -255,7 +255,7 @@ class Leader(Application):
                 follower.receive_recording_event(recording_event)
 
 
-class ProcessApplication(Leader, Follower, ABC):
+class ProcessApplication(Leader, Follower):
     """
     Base class for event processing applications
     that are both "leaders" and followers".
@@ -1247,6 +1247,6 @@ class NotificationLogReader:
             if len(notifications) == 0:
                 break
 
-            # Otherwise yield and continue.
+            # Otherwise, yield and continue.
             yield notifications
             start = notifications[-1].id + 1
