@@ -36,6 +36,8 @@ from eventsourcing.utils import Environment, get_topic
 
 
 class AggregateRecorderTestCase(TestCase, ABC):
+    INITIAL_VERSION = 1
+
     @abstractmethod
     def create_recorder(self) -> AggregateRecorder:
         """"""
@@ -59,7 +61,7 @@ class AggregateRecorderTestCase(TestCase, ABC):
         # Write a stored event.
         stored_event1 = StoredEvent(
             originator_id=originator_id1,
-            originator_version=0,
+            originator_version=self.INITIAL_VERSION,
             topic="topic1",
             state=b"state1",
         )
@@ -70,7 +72,7 @@ class AggregateRecorderTestCase(TestCase, ABC):
         stored_events = recorder.select_events(originator_id1)
         self.assertEqual(len(stored_events), 1)
         assert stored_events[0].originator_id == originator_id1
-        assert stored_events[0].originator_version == 0
+        assert stored_events[0].originator_version == self.INITIAL_VERSION
         assert stored_events[0].topic == "topic1"
 
         # Check get record conflict error if attempt to store it again.
@@ -81,7 +83,7 @@ class AggregateRecorderTestCase(TestCase, ABC):
         # Check writing of events is atomic.
         stored_event2 = StoredEvent(
             originator_id=originator_id1,
-            originator_version=1,
+            originator_version=self.INITIAL_VERSION + 1,
             topic="topic2",
             state=b"state2",
         )
@@ -94,14 +96,14 @@ class AggregateRecorderTestCase(TestCase, ABC):
         # Check still only have one record.
         stored_events = recorder.select_events(originator_id1)
         self.assertEqual(len(stored_events), 1)
-        assert stored_events[0].originator_id == originator_id1
-        assert stored_events[0].originator_version == 0
-        assert stored_events[0].topic == "topic1"
+        assert stored_events[0].originator_id == stored_event1.originator_id
+        assert stored_events[0].originator_version == stored_event1.originator_version
+        assert stored_events[0].topic == stored_event1.topic
 
         # Check can write two events together.
         stored_event3 = StoredEvent(
             originator_id=originator_id1,
-            originator_version=2,
+            originator_version=self.INITIAL_VERSION + 2,
             topic="topic3",
             state=b"state3",
         )
@@ -112,46 +114,46 @@ class AggregateRecorderTestCase(TestCase, ABC):
         stored_events = recorder.select_events(originator_id1)
         self.assertEqual(len(stored_events), 3)
         assert stored_events[0].originator_id == originator_id1
-        assert stored_events[0].originator_version == 0
+        assert stored_events[0].originator_version == self.INITIAL_VERSION
         assert stored_events[0].topic == "topic1"
         self.assertEqual(stored_events[0].state, b"state1")
         assert stored_events[1].originator_id == originator_id1
-        assert stored_events[1].originator_version == 1
+        assert stored_events[1].originator_version == self.INITIAL_VERSION + 1
         assert stored_events[1].topic == "topic2"
         assert stored_events[1].state == b"state2"
         assert stored_events[2].originator_id == originator_id1
-        assert stored_events[2].originator_version == 2
+        assert stored_events[2].originator_version == self.INITIAL_VERSION + 2
         assert stored_events[2].topic == "topic3"
         assert stored_events[2].state == b"state3"
 
         # Check we can get the last one recorded (used to get last snapshot).
-        events = recorder.select_events(originator_id1, desc=True, limit=1)
-        self.assertEqual(len(events), 1)
+        stored_events = recorder.select_events(originator_id1, desc=True, limit=1)
+        self.assertEqual(len(stored_events), 1)
         self.assertEqual(
-            events[0],
+            stored_events[0],
             stored_event3,
         )
 
         # Check we can get the last one before a particular version.
-        events = recorder.select_events(originator_id1, lte=1, desc=True, limit=1)
+        stored_events = recorder.select_events(
+            originator_id1, lte=self.INITIAL_VERSION + 1, desc=True, limit=1
+        )
+        self.assertEqual(len(stored_events), 1)
+        self.assertEqual(
+            stored_events[0],
+            stored_event2,
+        )
+
+        # Check we can get events between versions (historical state with snapshot).
+        events = recorder.select_events(
+            originator_id1, gt=self.INITIAL_VERSION, lte=self.INITIAL_VERSION + 1
+        )
         self.assertEqual(len(events), 1)
         self.assertEqual(
             events[0],
             stored_event2,
         )
 
-        # Check we can get events between particular versions.
-        events = recorder.select_events(originator_id1, gt=0, lte=2)
-        self.assertEqual(len(events), 2)
-        self.assertEqual(
-            events[0],
-            stored_event2,
-        )
-        self.assertEqual(
-            events[1],
-            stored_event3,
-        )
-
         # Check aggregate sequences are distinguished.
         originator_id2 = uuid4()
         self.assertEqual(
@@ -159,7 +161,7 @@ class AggregateRecorderTestCase(TestCase, ABC):
             [],
         )
 
-        # Write a stored event.
+        # Write a stored event in a different sequence.
         stored_event4 = StoredEvent(
             originator_id=originator_id2,
             originator_version=0,
@@ -182,7 +184,7 @@ class AggregateRecorderTestCase(TestCase, ABC):
 
             stored_event = StoredEvent(
                 originator_id=originator_id,
-                originator_version=0,
+                originator_version=self.INITIAL_VERSION,
                 topic="topic1",
                 state=b"state1",
             )
@@ -202,6 +204,8 @@ class AggregateRecorderTestCase(TestCase, ABC):
 
 
 class ApplicationRecorderTestCase(TestCase, ABC):
+    INITIAL_VERSION = 1
+
     @abstractmethod
     def create_recorder(self) -> ApplicationRecorder:
         """"""
@@ -210,17 +214,23 @@ class ApplicationRecorderTestCase(TestCase, ABC):
         # Construct the recorder.
         recorder = self.create_recorder()
 
+        max_notification_id = recorder.max_notification_id()
+
         # Check notifications methods work when there aren't any.
         self.assertEqual(
             recorder.max_notification_id(),
+            max_notification_id,
+        )
+        self.assertEqual(
+            len(recorder.select_notifications(max_notification_id + 1, 3)),
             0,
         )
         self.assertEqual(
-            len(recorder.select_notifications(1, 3)),
-            0,
-        )
-        self.assertEqual(
-            len(recorder.select_notifications(1, 3, topics=["topic1"])),
+            len(
+                recorder.select_notifications(
+                    max_notification_id + 1, 3, topics=["topic1"]
+                )
+            ),
             0,
         )
 
@@ -230,19 +240,19 @@ class ApplicationRecorderTestCase(TestCase, ABC):
 
         stored_event1 = StoredEvent(
             originator_id=originator_id1,
-            originator_version=0,
+            originator_version=self.INITIAL_VERSION,
             topic="topic1",
             state=b"state1",
         )
         stored_event2 = StoredEvent(
             originator_id=originator_id1,
-            originator_version=1,
+            originator_version=self.INITIAL_VERSION + 1,
             topic="topic2",
             state=b"state2",
         )
         stored_event3 = StoredEvent(
             originator_id=originator_id2,
-            originator_version=1,
+            originator_version=self.INITIAL_VERSION,
             topic="topic3",
             state=b"state3",
         )
@@ -251,10 +261,12 @@ class ApplicationRecorderTestCase(TestCase, ABC):
         self.assertEqual(notification_ids, [])
 
         notification_ids = recorder.insert_events([stored_event1, stored_event2])
-        self.assertEqual(notification_ids, [1, 2])
+        self.assertEqual(
+            notification_ids, [max_notification_id + 1, max_notification_id + 2]
+        )
 
         notification_ids = recorder.insert_events([stored_event3])
-        self.assertEqual(notification_ids, [3])
+        self.assertEqual(notification_ids, [max_notification_id + 3])
 
         stored_events1 = recorder.select_events(originator_id1)
         stored_events2 = recorder.select_events(originator_id2)
@@ -263,99 +275,112 @@ class ApplicationRecorderTestCase(TestCase, ABC):
         self.assertEqual(len(stored_events1), 2)
         self.assertEqual(len(stored_events2), 1)
 
-        notifications = recorder.select_notifications(1, 3)
+        sleep(1)  # Added to make eventsourcing-axon tests work, perhaps not necessary.
+        notifications = recorder.select_notifications(max_notification_id + 1, 3)
         self.assertEqual(len(notifications), 3)
-        self.assertEqual(notifications[0].id, 1)
+        self.assertEqual(notifications[0].id, max_notification_id + 1)
         self.assertEqual(notifications[0].originator_id, originator_id1)
         self.assertEqual(notifications[0].topic, "topic1")
         self.assertEqual(notifications[0].state, b"state1")
-        self.assertEqual(notifications[1].id, 2)
+        self.assertEqual(notifications[1].id, max_notification_id + 2)
         self.assertEqual(notifications[1].originator_id, originator_id1)
         self.assertEqual(notifications[1].topic, "topic2")
         self.assertEqual(notifications[1].state, b"state2")
-        self.assertEqual(notifications[2].id, 3)
+        self.assertEqual(notifications[2].id, max_notification_id + 3)
         self.assertEqual(notifications[2].originator_id, originator_id2)
         self.assertEqual(notifications[2].topic, "topic3")
         self.assertEqual(notifications[2].state, b"state3")
 
         notifications = recorder.select_notifications(
-            1, 3, topics=["topic1", "topic2", "topic3"]
+            max_notification_id + 1, 3, topics=["topic1", "topic2", "topic3"]
         )
         self.assertEqual(len(notifications), 3)
-        self.assertEqual(notifications[0].id, 1)
+        self.assertEqual(notifications[0].id, max_notification_id + 1)
         self.assertEqual(notifications[0].originator_id, originator_id1)
         self.assertEqual(notifications[0].topic, "topic1")
         self.assertEqual(notifications[0].state, b"state1")
-        self.assertEqual(notifications[1].id, 2)
+        self.assertEqual(notifications[1].id, max_notification_id + 2)
         self.assertEqual(notifications[1].originator_id, originator_id1)
         self.assertEqual(notifications[1].topic, "topic2")
         self.assertEqual(notifications[1].state, b"state2")
-        self.assertEqual(notifications[2].id, 3)
+        self.assertEqual(notifications[2].id, max_notification_id + 3)
         self.assertEqual(notifications[2].originator_id, originator_id2)
         self.assertEqual(notifications[2].topic, "topic3")
         self.assertEqual(notifications[2].state, b"state3")
 
-        notifications = recorder.select_notifications(1, 3, topics=["topic1"])
+        notifications = recorder.select_notifications(
+            max_notification_id + 1, 3, topics=["topic1"]
+        )
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0].id, 1)
+        self.assertEqual(notifications[0].id, max_notification_id + 1)
         self.assertEqual(notifications[0].originator_id, originator_id1)
         self.assertEqual(notifications[0].topic, "topic1")
         self.assertEqual(notifications[0].state, b"state1")
 
-        notifications = recorder.select_notifications(1, 3, topics=["topic2"])
+        notifications = recorder.select_notifications(
+            max_notification_id + 1, 3, topics=["topic2"]
+        )
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0].id, 2)
+        self.assertEqual(notifications[0].id, max_notification_id + 2)
         self.assertEqual(notifications[0].originator_id, originator_id1)
         self.assertEqual(notifications[0].topic, "topic2")
         self.assertEqual(notifications[0].state, b"state2")
 
-        notifications = recorder.select_notifications(1, 3, topics=["topic3"])
+        notifications = recorder.select_notifications(
+            max_notification_id + 1, 3, topics=["topic3"]
+        )
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0].id, 3)
+        self.assertEqual(notifications[0].id, max_notification_id + 3)
         self.assertEqual(notifications[0].originator_id, originator_id2)
         self.assertEqual(notifications[0].topic, "topic3")
         self.assertEqual(notifications[0].state, b"state3")
 
-        notifications = recorder.select_notifications(1, 3, topics=["topic1", "topic3"])
+        notifications = recorder.select_notifications(
+            max_notification_id + 1, 3, topics=["topic1", "topic3"]
+        )
         self.assertEqual(len(notifications), 2)
-        self.assertEqual(notifications[0].id, 1)
+        self.assertEqual(notifications[0].id, max_notification_id + 1)
         self.assertEqual(notifications[0].originator_id, originator_id1)
         self.assertEqual(notifications[0].topic, "topic1")
         self.assertEqual(notifications[0].state, b"state1")
-        self.assertEqual(notifications[1].id, 3)
+        self.assertEqual(notifications[1].id, max_notification_id + 3)
         self.assertEqual(notifications[1].topic, "topic3")
         self.assertEqual(notifications[1].state, b"state3")
 
         self.assertEqual(
             recorder.max_notification_id(),
-            3,
+            max_notification_id + 3,
         )
 
-        notifications = recorder.select_notifications(1, 1)
+        notifications = recorder.select_notifications(max_notification_id + 1, 1)
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0].id, 1)
+        self.assertEqual(notifications[0].id, max_notification_id + 1)
 
-        notifications = recorder.select_notifications(2, 1)
+        notifications = recorder.select_notifications(max_notification_id + 2, 1)
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0].id, 2)
+        self.assertEqual(notifications[0].id, max_notification_id + 2)
 
-        notifications = recorder.select_notifications(2, 2)
+        notifications = recorder.select_notifications(max_notification_id + 2, 2)
         self.assertEqual(len(notifications), 2)
-        self.assertEqual(notifications[0].id, 2)
-        self.assertEqual(notifications[1].id, 3)
+        self.assertEqual(notifications[0].id, max_notification_id + 2)
+        self.assertEqual(notifications[1].id, max_notification_id + 3)
 
-        notifications = recorder.select_notifications(3, 1)
-        self.assertEqual(len(notifications), 1, len(notifications))
-        self.assertEqual(notifications[0].id, 3)
-
-        notifications = recorder.select_notifications(start=2, limit=10, stop=2)
+        notifications = recorder.select_notifications(max_notification_id + 3, 1)
         self.assertEqual(len(notifications), 1)
-        self.assertEqual(notifications[0].id, 2)
+        self.assertEqual(notifications[0].id, max_notification_id + 3)
 
-        notifications = recorder.select_notifications(start=1, limit=10, stop=2)
+        notifications = recorder.select_notifications(
+            start=max_notification_id + 2, limit=10, stop=max_notification_id + 2
+        )
+        self.assertEqual(len(notifications), 1)
+        self.assertEqual(notifications[0].id, max_notification_id + 2)
+
+        notifications = recorder.select_notifications(
+            start=max_notification_id + 1, limit=10, stop=max_notification_id + 2
+        )
         self.assertEqual(len(notifications), 2, len(notifications))
-        self.assertEqual(notifications[0].id, 1)
-        self.assertEqual(notifications[1].id, 2)
+        self.assertEqual(notifications[0].id, max_notification_id + 1)
+        self.assertEqual(notifications[1].id, max_notification_id + 2)
 
     def test_concurrent_no_conflicts(self) -> None:
         print(self)
@@ -713,6 +738,8 @@ class NonInterleavingNotificationIDsBaseCase(ABC, TestCase):
     def test(self):
         recorder = self.create_recorder()
 
+        max_notification_id = recorder.max_notification_id()
+
         race_started = Event()
 
         originator1_id = uuid4()
@@ -744,13 +771,19 @@ class NonInterleavingNotificationIDsBaseCase(ABC, TestCase):
         if errors:
             raise errors[0]
 
-        notifications = recorder.select_notifications(start=1, limit=1000000)
+        sleep(1)  # Added to make eventsourcing-axon tests work, perhaps not necessary.
+        notifications = recorder.select_notifications(
+            start=max_notification_id + 1, limit=2 * self.insert_num
+        )
         ids_for_sequence1 = [
             e.id for e in notifications if e.originator_id == originator1_id
         ]
         ids_for_sequence2 = [
             e.id for e in notifications if e.originator_id == originator2_id
         ]
+        self.assertEqual(self.insert_num, len(ids_for_sequence1))
+        self.assertEqual(self.insert_num, len(ids_for_sequence2))
+
         max_id_for_sequence1 = max(ids_for_sequence1)
         max_id_for_sequence2 = max(ids_for_sequence2)
         min_id_for_sequence1 = min(ids_for_sequence1)
@@ -766,8 +799,8 @@ class NonInterleavingNotificationIDsBaseCase(ABC, TestCase):
             StoredEvent(
                 originator_id=originator_id,
                 originator_version=i,
-                topic="",
-                state=b"",
+                topic="non-interleaving-test-event",
+                state=b"{}",
             )
             for i in range(self.insert_num)
         ]
